__all__ = ["seg",
    "nearby", 
    "compare", 
    "display", 
    "keywords",
    "KeyedVectors", 
    "any2utf8",
    "sigmoid",
    "cosine",
    "any2unicode",
    "np",
    "v",
    "__version__"]

from .word2vec import *
from .synonyms import *
from .synonyms import __version__